#include "test.h"

namespace tester {

   inline test::test(TString fName) {
      gROOT->ProcessLine("#include <vector>"); // dumb root stuff
      fChain = new TChain("test_tree");
      fChain->Add(fName);
      nEvent = fChain->GetEntries();
      cout << "Chain has " << nEvent << " events" << endl;
      to_get.push_back("pt");
      to_get.push_back("eta");
      to_get.push_back("phi");
      to_get.push_back("E");
   }

   void test::LoadEvent(Long64_t& ientry) {
      cout << "Loading event " << ientry << endl; 
      entry=ientry;
      Long64_t jentry = fChain->LoadTree(entry);
      fChain->GetEntry(jentry);
   }; // LoadEvent

   void test::GetBranches() {
      TString prefix = "jet";
      TString var(prefix);
      // properties
      for(vector<TString>::const_iterator p = to_get.begin(); p != to_get.end(); p++) {
	 var = (prefix+"_"+*p);
	 cout << "Looking for " << var << endl;
	 if(!(fChain->FindBranch(var.Data()))) { continue; }
	 TBranch* btmp = 0; vector<float>* vftmp = 0;
	 fChain->SetBranchAddress(var,&vftmp,&btmp);
	 if(!btmp) { cout << "Cannot find TBranch " << var << " in TTree" << endl; }
	 btmp->GetEntry(entry);
	 if(!vftmp) { cout << "No vector loaded from TBranch " << var << endl; }
	 cout << "vector size " << vftmp->size() << endl;
	 brnchs.push_back(btmp);
	 v_props.push_back(vftmp);
      }
   } // GetBranches

   void test::DumpProperties() {
      for(vector<TBranch*>::const_iterator br =  brnchs.begin(); br != brnchs.end(); br++) {
	 (*br)->GetEntry(entry);
      }
      if(v_props.size()==0) { return; }
      for(int j=0; j<(int)v_props[0]->size(); j++) {
	 cout << j << "\t";
	 for(int k=0; k<(int)to_get.size(); k++) {
	    cout << v_props[j]->at(k) << "\t";
	 }
	 cout << endl;
      }

   }

   //--------------------------------------------------------
   //--------------------------------------------------------
   //--------------------------------------------------------

   void test::Run() {

      cout <<endl<<"================= Start Event Loop ================="<<endl<<endl;
      
      Long64_t nbytes = 0, nb = 0;
      for (Long64_t ientry=0; ientry<nEvent;ientry++) {
	 LoadEvent(ientry);
	 DumpProperties();
      } // event loop
      return;
   } // Run

} //end of namespace

//--------------------------------------------------------------
//--------------------------------------------------------------
//--------------------------------------------------------------

int main(int argc, char* argv[]) {

   TString fName = "test_file.root";

   tester::test* atest = new tester::test(fName);
   atest->GetBranches();
   atest->Run();

   return 1;
}



